# atelParser

<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/atelParser)](https://pypi.org/project/atelParser/)  
[![](https://img.shields.io/pypi/v/atelParser)](https://pypi.org/project/atelParser/)  
[![](https://img.shields.io/github/license/thespacedoctor/atelParser)](https://github.com/thespacedoctor/atelParser)  
[![](https://img.shields.io/pypi/dm/atelParser)](https://pypi.org/project/atelParser/)  

<!-- STATUS BADGES -->  

[![](http://167.99.90.204:8080/buildStatus/icon?job=atelParser%2Fmaster&subject=build%20master)](http://167.99.90.204:8080/blue/organizations/jenkins/atelParser/activity?branch=master)  
[![](http://167.99.90.204:8080/buildStatus/icon?job=atelParser%2Fdevelop&subject=build%20dev)](http://167.99.90.204:8080/blue/organizations/jenkins/atelParser/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/atelParser@master/coverage.svg)](https://raw.githack.com/thespacedoctor/atelParser/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/atelParser/badge/)](http://atelParser.readthedocs.io/en/latest/?badge)  
[![](https://img.shields.io/github/issues/thespacedoctor/atelParser/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/atelParser/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*scrape and parse content of ATels posted on The Astronomer's Telegram website, identify individual objects by name and coordinates*.

Documentation for atelParser is hosted by [Read the Docs](http://atelParser.readthedocs.org/en/stable/) (last
[stable version](http://atelParser.readthedocs.org/en/stable/) and [latest version](http://atelParser.readthedocs.org/en/latest/)). The code lives on [github](https://github.com/thespacedoctor/atelParser). Please report any issues you find [here](https://github.com/thespacedoctor/atelParser/issues).

## Features

* 



